@@ -452,9 +452,11 @@ func (ctx *restoreContext) execute() (Result, Result) {
 	}()
 
 	// totalItems: previously discovered items, i: iteration counter.
-	totalItems, i, existingNamespaces := 0, 0, sets.NewString()
+	totalItems, processedItems, existingNamespaces := 0, 0, sets.NewString()
 
-	// First restore only CRDs
+	// First restore CRDs. This is needed so that they are available in the cluster
+	// when getOrderedResourceCollection is called again on the whole backup and
+	// needs to validate all resources listed.
 	crdResourceCollection, processedResources, w, e := ctx.getOrderedResourceCollection(
 		backupResources,
 		make([]restoreableResource, 0),
@@ -471,7 +473,14 @@ func (ctx *restoreContext) execute() (Result, Result) {
 
 	for _, selectedResource := range crdResourceCollection {
 		var w, e Result
-		i, w, e = ctx.processSelectedResource(selectedResource, totalItems, i, existingNamespaces, update)
+		// Restore this resource
+		processedItems, w, e = ctx.processSelectedResource(
+			selectedResource,
+			totalItems,
+			processedItems,
+			existingNamespaces,
+			update,
+		)
 		warnings.Merge(&w)
 		errs.Merge(&e)
 	}
@@ -487,8 +496,8 @@ func (ctx *restoreContext) execute() (Result, Result) {
 	warnings.Merge(&w)
 	errs.Merge(&e)
 
-	// reset i and totalItems after processing full resource list
-	i = 0
+	// reset processedItems and totalItems before processing full resource list
+	processedItems = 0
 	totalItems = 0
 	for _, selectedResource := range selectedResourceCollection {
 		totalItems += selectedResource.totalItems
@@ -496,7 +505,14 @@ func (ctx *restoreContext) execute() (Result, Result) {
 
 	for _, selectedResource := range selectedResourceCollection {
 		var w, e Result
-		i, w, e = ctx.processSelectedResource(selectedResource, totalItems, i, existingNamespaces, update)
+		// Restore this resource
+		processedItems, w, e = ctx.processSelectedResource(
+			selectedResource,
+			totalItems,
+			processedItems,
+			existingNamespaces,
+			update,
+		)
 		warnings.Merge(&w)
 		errs.Merge(&e)
 	}
@@ -560,10 +576,13 @@ func (ctx *restoreContext) execute() (Result, Result) {
 	return warnings, errs
 }
 
+// Process and restore one restoreableResource from the backup and update restore progress
+// metadata. At this point, the resource has already been validated and counted for inclusion
+// in the expected total restore count.
 func (ctx *restoreContext) processSelectedResource(
 	selectedResource restoreableResource,
 	totalItems int,
-	i int,
+	processedItems int,
 	existingNamespaces sets.String,
 	update chan progressUpdate,
 ) (int, Result, Result) {
@@ -625,14 +644,14 @@ func (ctx *restoreContext) processSelectedResource(
 			w, e := ctx.restoreItem(obj, groupResource, selectedItem.targetNamespace)
 			warnings.Merge(&w)
 			errs.Merge(&e)
-			i++
+			processedItems++
 
 			// totalItems keeps the count of items previously known. There
 			// may be additional items restored by plugins. We want to include
 			// the additional items by looking at restoredItems at the same
 			// time, we don't want previously known items counted twice as
 			// they are present in both restoredItems and totalItems.
-			actualTotalItems := len(ctx.restoredItems) + (totalItems - i)
+			actualTotalItems := len(ctx.restoredItems) + (totalItems - processedItems)
 			update <- progressUpdate{
 				totalItems:    actualTotalItems,
 				itemsRestored: len(ctx.restoredItems),
@@ -655,7 +674,7 @@ func (ctx *restoreContext) processSelectedResource(
 			warnings.Add("", errors.Wrap(err, "refresh discovery after restoring CRDs"))
 		}
 	}
-	return i, warnings, errs
+	return processedItems, warnings, errs
 }
 
 // getNamespace returns a namespace API object that we should attempt to
@@ -1316,8 +1335,16 @@ func (ctx *restoreContext) restoreItem(obj *unstructured.Unstructured, groupReso
 		return warnings, errs
 	}
 
-	if groupResource == kuberesource.Pods && len(restic.GetVolumeBackupsForPod(ctx.podVolumeBackups, obj, originalNamespace)) > 0 {
-		restorePodVolumeBackups(ctx, createdObj, originalNamespace)
+	if groupResource == kuberesource.Pods {
+		pod := new(v1.Pod)
+		if err := runtime.DefaultUnstructuredConverter.FromUnstructured(obj.UnstructuredContent(), pod); err != nil {
+			errs.Add(namespace, err)
+			return warnings, errs
+		}
+
+		if len(restic.GetVolumeBackupsForPod(ctx.podVolumeBackups, pod, originalNamespace)) > 0 {
+			restorePodVolumeBackups(ctx, createdObj, originalNamespace)
+		}
 	}
 
 	if groupResource == kuberesource.Pods {
